summaryrefslogtreecommitdiff
path: root/src/exceptions.h
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2020-04-14 20:16:44 +0200
committerCarl Hetherington <cth@carlh.net>2020-04-14 20:16:44 +0200
commit4d6c8aaf0167cde3bb63e9014604243bdc47b1a1 (patch)
tree13aae09fb07326febeb401930718692b45df2cff /src/exceptions.h
parent314060f975dc9806f49ec8bbb1c11041a2ac111f (diff)
s/DCPReadError/ReadError/g
Diffstat (limited to 'src/exceptions.h')
-rw-r--r--src/exceptions.h16
1 files changed, 9 insertions, 7 deletions
diff --git a/src/exceptions.h b/src/exceptions.h
index 770bd916..cd4f5fbb 100644
--- a/src/exceptions.h
+++ b/src/exceptions.h
@@ -91,20 +91,21 @@ public:
{}
};
-/** @class DCPReadError
- * @brief A DCP read exception
+
+/** @class ReadError
+ * @brief Any error that occurs when reading data from a DCP.
*/
-class DCPReadError : public std::runtime_error
+class ReadError : public std::runtime_error
{
public:
- explicit DCPReadError (std::string message)
+ explicit ReadError (std::string message)
: std::runtime_error(message)
, _message(message)
{}
- DCPReadError (std::string message, std::string detail);
+ ReadError (std::string message, std::string detail);
- ~DCPReadError() throw () {}
+ ~ReadError() throw () {}
std::string message () const {
return _message;
@@ -119,7 +120,8 @@ private:
boost::optional<std::string> _detail;
};
-class BadContentKindError : public DCPReadError
+
+class BadContentKindError : public ReadError
{
public:
BadContentKindError (std::string content_kind);